# coding: utf-8

"""
    Lookup/Ibis web service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class PersonIdentifier(BaseModel):
    """
    PersonIdentifier
    """
    scheme: Optional[StrictStr] = Field(None, description="The identifier's scheme (e.g., \"crsid\").")
    value: Optional[StrictStr] = Field(None, description="The identifier's value in that scheme (e.g., a specific CRSid value).")
    __properties = ["scheme", "value"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PersonIdentifier:
        """Create an instance of PersonIdentifier from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PersonIdentifier:
        """Create an instance of PersonIdentifier from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PersonIdentifier.parse_obj(obj)

        _obj = PersonIdentifier.parse_obj({
            "scheme": obj.get("scheme"),
            "value": obj.get("value")
        })
        return _obj


